@@ -22,6 +22,7 @@ from typing import Any, Awaitable, Dict, Iterable, List, Optional, Union
 import comet_mpm.event
 import comet_mpm.events_from_dataframe
 
+from . import optional_update
 from .connection import MPM_BASE_PATH, REST_API_BASE_PATH, sanitize_url, url_join
 from .constants import (
     EVENT_FEATURES,
@@ -57,6 +58,8 @@ class CometMPM:
         model_version: Optional[str] = None,
         disabled: Optional[bool] = None,
         asyncio: bool = False,
+        max_batch_size: Optional[int] = None,
+        max_batch_time: Optional[int] = None,
     ):
         """
         Creates the Comet MPM Event logger object.
@@ -67,21 +70,22 @@ class CometMPM:
             model_version: The Comet Model Version of the model
             disabled: If set to True, CometMPM will not send anything to the backend.
             asyncio: Set to True if you are using an Asyncio-based framework like FastAPI.
+            max_batch_size: Maximum number of MPM events sent in a batch, can also be configured using the environment variable MPM_MAX_BATCH_SIZE.
+            max_batch_time: Maximum time before a batch of events is submitted to MPM, can also be configured using the environment variable MPM_MAX_BATCH_SIZE.
         """
 
-        settings_user_values = {}  # type: Dict[str, str]
-        # Filter out None
-        if api_key is not None:
-            settings_user_values["api_key"] = api_key
-
-        if model_name is not None:
-            settings_user_values["mpm_model_name"] = model_name
-
-        if model_version is not None:
-            settings_user_values["mpm_model_version"] = model_version
-
-        if workspace_name is not None:
-            settings_user_values["mpm_workspace_name"] = workspace_name
+        settings_user_values = {}  # type: Dict[str, str|int]
+        optional_update.update(
+            settings_user_values,
+            {
+                "api_key": api_key,
+                "mpm_model_name": model_name,
+                "mpm_model_version": model_version,
+                "mpm_workspace_name": workspace_name,
+                "mpm_max_batch_size": max_batch_size,
+                "mpm_max_batch_time": max_batch_time,
+            },
+        )
 
         self._settings = get_model(
             MPMSettings,
